@@ -2,7 +2,7 @@
 
 from docx.api import Document  # noqa
 
-__version__ = '0.8.5'
+__version__ = '0.8.7'
 
 
 # register custom Part classes with opc package reader
@@ -14,6 +14,7 @@ from docx.opc.parts.coreprops import CorePropertiesPart
 from docx.parts.document import DocumentPart
 from docx.parts.image import ImagePart
 from docx.parts.numbering import NumberingPart
+from docx.parts.settings import SettingsPart
 from docx.parts.styles import StylesPart
 
 
@@ -27,6 +28,7 @@ PartFactory.part_class_selector = part_class_selector
 PartFactory.part_type_for[CT.OPC_CORE_PROPERTIES] = CorePropertiesPart
 PartFactory.part_type_for[CT.WML_DOCUMENT_MAIN] = DocumentPart
 PartFactory.part_type_for[CT.WML_NUMBERING] = NumberingPart
+PartFactory.part_type_for[CT.WML_SETTINGS] = SettingsPart
 PartFactory.part_type_for[CT.WML_STYLES] = StylesPart
 
 del (
