@@ -1,14 +1,13 @@
 # encoding: utf-8
 
-"""
-Custom element classes for tables
-"""
+"""Custom element classes for tables"""
 
 from __future__ import (
     absolute_import, division, print_function, unicode_literals
 )
 
 from . import parse_xml
+from ..enum.table import WD_CELL_VERTICAL_ALIGNMENT, WD_ROW_HEIGHT_RULE
 from ..exceptions import InvalidSpanError
 from .ns import nsdecls, qn
 from ..shared import Emu, Twips
@@ -21,6 +20,14 @@ from .xmlchemy import (
 )
 
 
+class CT_Height(BaseOxmlElement):
+    """
+    Used for ``<w:trHeight>`` to specify a row height and row height rule.
+    """
+    val = OptionalAttribute('w:val', ST_TwipsMeasure)
+    hRule = OptionalAttribute('w:hRule', WD_ROW_HEIGHT_RULE)
+
+
 class CT_Row(BaseOxmlElement):
     """
     ``<w:tr>`` element
@@ -51,6 +58,38 @@ class CT_Row(BaseOxmlElement):
         """
         return self.getparent().tr_lst.index(self)
 
+    @property
+    def trHeight_hRule(self):
+        """
+        Return the value of `w:trPr/w:trHeight@w:hRule`, or |None| if not
+        present.
+        """
+        trPr = self.trPr
+        if trPr is None:
+            return None
+        return trPr.trHeight_hRule
+
+    @trHeight_hRule.setter
+    def trHeight_hRule(self, value):
+        trPr = self.get_or_add_trPr()
+        trPr.trHeight_hRule = value
+
+    @property
+    def trHeight_val(self):
+        """
+        Return the value of `w:trPr/w:trHeight@w:val`, or |None| if not
+        present.
+        """
+        trPr = self.trPr
+        if trPr is None:
+            return None
+        return trPr.trHeight_val
+
+    @trHeight_val.setter
+    def trHeight_val(self, value):
+        trPr = self.get_or_add_trPr()
+        trPr.trHeight_val = value
+
     def _insert_tblPrEx(self, tblPrEx):
         self.insert(0, tblPrEx)
 
@@ -651,7 +690,7 @@ class CT_Tc(BaseOxmlElement):
         """
         The tbl element this tc element appears in.
         """
-        return self.xpath('./ancestor::w:tbl')[0]
+        return self.xpath('./ancestor::w:tbl[position()=1]')[0]
 
     @property
     def _tc_above(self):
@@ -675,7 +714,7 @@ class CT_Tc(BaseOxmlElement):
         """
         The tr element this tc element appears in.
         """
-        return self.xpath('./ancestor::w:tr')[0]
+        return self.xpath('./ancestor::w:tr[position()=1]')[0]
 
     @property
     def _tr_above(self):
@@ -723,6 +762,7 @@ class CT_TcPr(BaseOxmlElement):
     tcW = ZeroOrOne('w:tcW', successors=_tag_seq[2:])
     gridSpan = ZeroOrOne('w:gridSpan', successors=_tag_seq[3:])
     vMerge = ZeroOrOne('w:vMerge', successors=_tag_seq[5:])
+    vAlign = ZeroOrOne('w:vAlign', successors=_tag_seq[12:])
     del _tag_seq
 
     @property
@@ -742,6 +782,25 @@ class CT_TcPr(BaseOxmlElement):
         if value > 1:
             self.get_or_add_gridSpan().val = value
 
+    @property
+    def vAlign_val(self):
+        """Value of `w:val` attribute on  `w:vAlign` child.
+
+        Value is |None| if `w:vAlign` child is not present. The `w:val`
+        attribute on `w:vAlign` is required.
+        """
+        vAlign = self.vAlign
+        if vAlign is None:
+            return None
+        return vAlign.val
+
+    @vAlign_val.setter
+    def vAlign_val(self, value):
+        if value is None:
+            self._remove_vAlign()
+            return
+        self.get_or_add_vAlign().val = value
+
     @property
     def vMerge_val(self):
         """
@@ -776,6 +835,59 @@ class CT_TcPr(BaseOxmlElement):
         tcW.width = value
 
 
+class CT_TrPr(BaseOxmlElement):
+    """
+    ``<w:trPr>`` element, defining table row properties
+    """
+    _tag_seq = (
+        'w:cnfStyle', 'w:divId', 'w:gridBefore', 'w:gridAfter', 'w:wBefore',
+        'w:wAfter', 'w:cantSplit', 'w:trHeight', 'w:tblHeader',
+        'w:tblCellSpacing', 'w:jc', 'w:hidden', 'w:ins', 'w:del',
+        'w:trPrChange'
+    )
+    trHeight = ZeroOrOne('w:trHeight', successors=_tag_seq[8:])
+    del _tag_seq
+
+    @property
+    def trHeight_hRule(self):
+        """
+        Return the value of `w:trHeight@w:hRule`, or |None| if not present.
+        """
+        trHeight = self.trHeight
+        if trHeight is None:
+            return None
+        return trHeight.hRule
+
+    @trHeight_hRule.setter
+    def trHeight_hRule(self, value):
+        if value is None and self.trHeight is None:
+            return
+        trHeight = self.get_or_add_trHeight()
+        trHeight.hRule = value
+
+    @property
+    def trHeight_val(self):
+        """
+        Return the value of `w:trHeight@w:val`, or |None| if not present.
+        """
+        trHeight = self.trHeight
+        if trHeight is None:
+            return None
+        return trHeight.val
+
+    @trHeight_val.setter
+    def trHeight_val(self, value):
+        if value is None and self.trHeight is None:
+            return
+        trHeight = self.get_or_add_trHeight()
+        trHeight.val = value
+
+
+class CT_VerticalJc(BaseOxmlElement):
+    """`w:vAlign` element, specifying vertical alignment of cell."""
+    val = RequiredAttribute('w:val', WD_CELL_VERTICAL_ALIGNMENT)
+
+
 class CT_VMerge(BaseOxmlElement):
     """
     ``<w:vMerge>`` element, specifying vertical merging behavior of a cell.
