@@ -15,6 +15,7 @@ from ..opc.part import XmlPart
 from ..oxml.shape import CT_Inline
 from ..shape import InlineShapes
 from ..shared import lazyproperty
+from .settings import SettingsPart
 from .styles import StylesPart
 
 
@@ -95,16 +96,17 @@ class DocumentPart(XmlPart):
 
     @property
     def next_id(self):
-        """
-        The next available positive integer id value in this document. Gaps
-        in id sequence are filled. The id attribute value is unique in the
-        document, without regard to the element type it appears on.
+        """Next available positive integer id value in this document.
+
+        Calculated by incrementing maximum existing id value. Gaps in the
+        existing id sequence are not filled. The id attribute value is unique
+        in the document, without regard to the element type it appears on.
         """
         id_str_lst = self._element.xpath('//@id')
         used_ids = [int(id_str) for id_str in id_str_lst if id_str.isdigit()]
-        for n in range(1, len(used_ids)+2):
-            if n not in used_ids:
-                return n
+        if not used_ids:
+            return 1
+        return max(used_ids) + 1
 
     @lazyproperty
     def numbering_part(self):
@@ -127,6 +129,14 @@ class DocumentPart(XmlPart):
         """
         self.package.save(path_or_stream)
 
+    @property
+    def settings(self):
+        """
+        A |Settings| object providing access to the settings in the settings
+        part of this document.
+        """
+        return self._settings_part.settings
+
     @property
     def styles(self):
         """
@@ -135,6 +145,20 @@ class DocumentPart(XmlPart):
         """
         return self._styles_part.styles
 
+    @property
+    def _settings_part(self):
+        """
+        A |SettingsPart| object providing access to the document-level
+        settings for this document. Creates a default settings part if one is
+        not present.
+        """
+        try:
+            return self.part_related_by(RT.SETTINGS)
+        except KeyError:
+            settings_part = SettingsPart.default(self.package)
+            self.relate_to(settings_part, RT.SETTINGS)
+            return settings_part
+
     @property
     def _styles_part(self):
         """
