@@ -16,6 +16,7 @@ from docx.enum.text import WD_BREAK
 from docx.opc.coreprops import CoreProperties
 from docx.parts.document import DocumentPart
 from docx.section import Section, Sections
+from docx.settings import Settings
 from docx.shape import InlineShape, InlineShapes
 from docx.shared import Length
 from docx.styles.styles import Styles
@@ -107,6 +108,10 @@ class DescribeDocument(object):
         Sections_.assert_called_once_with(document._element)
         assert sections is sections_
 
+    def it_provides_access_to_its_settings(self, settings_fixture):
+        document, settings_ = settings_fixture
+        assert document.settings is settings_
+
     def it_provides_access_to_its_styles(self, styles_fixture):
         document, styles_ = styles_fixture
         assert document.styles is styles_
@@ -253,6 +258,12 @@ class DescribeDocument(object):
         Sections_.return_value = sections_
         return document, Sections_, sections_
 
+    @pytest.fixture
+    def settings_fixture(self, document_part_, settings_):
+        document = Document(None, document_part_)
+        document_part_.settings = settings_
+        return document, settings_
+
     @pytest.fixture
     def styles_fixture(self, document_part_, styles_):
         document = Document(None, document_part_)
@@ -335,6 +346,10 @@ class DescribeDocument(object):
     def sections_prop_(self, request):
         return property_mock(request, Document, 'sections')
 
+    @pytest.fixture
+    def settings_(self, request):
+        return instance_mock(request, Settings)
+
     @pytest.fixture
     def styles_(self, request):
         return instance_mock(request, Styles)
